/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.model.message;

public class Notification {

  private String title;
  private String description;
  private String additionalInformation;

  public Notification() {

  }

  public Notification(String title, String description) {
    super();
    this.title = title;
    this.description = description;
  }

  public Notification(String title, String description,
                      String additionalInformation) {
    super();
    this.title = title;
    this.description = description;
    this.additionalInformation = additionalInformation;
  }

  public Notification(NotificationType notificationType, String additionalInformation) {
    this(notificationType.title(), notificationType.description(), additionalInformation);
  }


  public String getTitle() {
    return title;
  }

  public void setTitle(String title) {
    this.title = title;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public String getAdditionalInformation() {
    return additionalInformation;
  }

  public void setAdditionalInformation(String additionalInformation) {
    this.additionalInformation = additionalInformation;
  }

  public String toString() {
    return String.format("Notification '%s' - '%s'",
            title,
            description
    );
  }
}
